#include <BH1750.h>
#include "DHT.h"
#include <SFE_BMP180.h>
#include <Wire.h>
#include <LCD5110_Graph.h>
#include "LowPower.h"

#define ALTITUDE 216.0 // Altitude in Sparta, Greece

#define DHTPIN 4  

#define DHTTYPE DHT22   

LCD5110 lcd(9,10,11,13,12);

SFE_BMP180 pressure;
extern unsigned char SmallFont[];
extern unsigned char TinyFont[];
float temperature;
int lightIntensity = 0;

DHT dht(DHTPIN, DHTTYPE);
BH1750 lightMeter;

void setup(void) {
  initLCD();
  lightMeter.begin();
  pressure.begin();
}

void loop() {

 float humidity, pressure; 
 readLight();
 if(lightIntensity>30)
 {
 lcd.disableSleep();
 dht.begin();
 delay(400);
 humidity = dht.readHumidity();
 temperature = dht.readTemperature();
 pressure = readPressure();
 
 lcd.clrScr(); 
 char tempF[6]; 
 char humF[6];
 char pressF[7];
 
 dtostrf(temperature, 5, 1, tempF);
 dtostrf(humidity, 5, 1, humF);
 dtostrf(pressure, 5, 1, pressF);

  //Print UI
  lcd.setFont(TinyFont);
  lcd.print("TEMP",LEFT+17,0);
  lcd.print("HUM",LEFT+62,0);
  lcd.print("PRESSURE",CENTER,30);

  lcd.setFont(SmallFont);
  //Printing Temperature
  lcd.print(tempF,LEFT,10);
  lcd.print("~C",LEFT+30,10);

  //Printing Humidity
  lcd.print(humF,LEFT+45,10);
  lcd.print("%",RIGHT,10);

  //Printing Pressure
  lcd.print(pressF,12,40);
  lcd.print(" hPa",48,40);

  lcd.update();

  sleepForTwoMinutes();
 }else
 {
    lcd.enableSleep();
    sleepForTwoMinutes();
 }
}


void initLCD()
{
  lcd.InitLCD();
  lcd.setFont(TinyFont);
  lcd.print("Weather Station v0.5",CENTER,0);
  lcd.update();
}

void sleepForTwoMinutes()
{

  for(int i=0;i<15;i++)
     LowPower.powerDown(SLEEP_8S, ADC_OFF, BOD_OFF); 
}
void readLight()
{
  delay(10);
  lightIntensity = lightMeter.readLightLevel();
}

float readPressure()
{
  char status;
  double T,P,p0,a;

  status = pressure.startTemperature();
  if (status != 0)
  {
    delay(status);
    status = pressure.getTemperature(T);
    if (status != 0)
    { 
      status = pressure.startPressure(3);
      if (status != 0)
      {
        delay(status);
        status = pressure.getPressure(P,T);
        if (status != 0)
        {
          p0 = pressure.sealevel(P,ALTITUDE);       
          return p0;
        }
      }
    }
  }
}
